@@ -1,4 +1,4 @@
 __version__ = '0.1.0'
 import webbrowser
-def let_me_google_that(What_do_you_want_to_google):
+def google(What_do_you_want_to_google):
     webbrowser.open("https://www.google.com/search?q=" + What_do_you_want_to_google)
